@@ -95,15 +95,15 @@ def get_template_from_request(request, page=None):
     """
     page_templates = settings.get_page_templates()
     if len(page_templates) == 0:
-        return settings.DEFAULT_PAGE_TEMPLATE
+        return settings.PAGE_DEFAULT_TEMPLATE
     template = request.REQUEST.get('template', None)
     if template is not None and \
             (template in dict(page_templates).keys() or
-            template == settings.DEFAULT_PAGE_TEMPLATE):
+            template == settings.PAGE_DEFAULT_TEMPLATE):
         return template
     if page is not None:
         return page.get_template()
-    return settings.DEFAULT_PAGE_TEMPLATE
+    return settings.PAGE_DEFAULT_TEMPLATE
 
 def get_language_from_request(request):
     """Return the most obvious language according the request."""
