@@ -1,6 +1,6 @@
 """Django page CMS test suite module"""
-from pages.tests.pages_tests import PagesTestCase
+from pages.tests.unittests import UnitTestCase
 from pages.tests.functionnal_tests import FunctionnalTestCase
 from pages.tests.auto_render import AutoRenderTestCase
 from pages.tests.regression_tests import RegressionTestCase
-from pages.tests.pages_link_tests import LinkTestCase
\ No newline at end of file
+from pages.tests.pages_link_tests import LinkTestCase
