@@ -1,3 +1,5 @@
+"""Django page CMS urls module."""
+
 from django.conf.urls.defaults import url, include, patterns
 from django.conf.urls.defaults import handler404, handler500
 from pages.views import details
@@ -10,7 +12,8 @@ urlpatterns = patterns('',
 
 if settings.PAGE_USE_LANGUAGE_PREFIX:
     urlpatterns += patterns('',
-        url(r'^(?P<lang>[-\w]+)/(?P<path>.*)$', details, name='pages-details-by-path')
+        url(r'^(?P<lang>[-\w]+)/(?P<path>.*)$', details,
+            name='pages-details-by-path')
     )
 else:
     urlpatterns += patterns('',
